from setuptools import setup

setup(name='stats_by_44',
      version='0.0',
      description='Gaussian & Binomail distributions',
      author='bobama',
      author_email='bobbmare@gmail.com',
      packages=['distributions'],
      zip_safe=False)
